(herald "Electronic Purchase with Money Order Protocol Variant"
  (comment "This version includes account numbers in exchanges"
    "This version uses sorts to avoid confusion"
    "between a nonce and other data"))

(comment "CPSA 2.2.0")
(comment "All input read")

(defprotocol sorted_epmo_acctnum basic
  (defrole bank
    (vars (b c m name) (acctnum price text) (hash name) (nc nm nb data))
    (trace (recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (annotations b
      (1
        (forall ((pm name))
          (implies
            (and (authtransfer c acctnum b price pm nm)
              (reqtransfer pm b price pm nm))
            (dotransfer acctnum b price pm nm))))
      (2
        (and (says c (authtransfer c acctnum b price m nm))
          (says m (reqtransfer m b price m nm))))))
  (defrole customer
    (vars (b c m hash name) (acctnum goods price text) (nc nm nb data))
    (trace (send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    (non-orig (privk b) (privk hash))
    (uniq-orig nc)
    (annotations c
      (1
        (says m
          (implies
            (exists ((acctnum2 text))
              (dotransfer acctnum2 b price m nm)) (doship m goods c))))
      (3
        (says b
          (forall ((pm name))
            (implies
              (and (authtransfer c acctnum b price m nm)
                (reqtransfer pm b price pm nm))
              (dotransfer acctnum b price pm nm)))))
      (4 (authtransfer c acctnum b price m nm))))
  (defrole merchant
    (vars (b c m hash name) (goods price text) (nc nm nb data))
    (trace (recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (uniq-orig nm)
    (annotations m
      (1
        (implies
          (exists ((acctnum2 text)) (dotransfer acctnum2 b price m nm))
          (doship m goods c)))
      (2
        (and
          (says b
            (forall ((pm name))
              (exists ((acctnum2 text))
                (implies
                  (and (authtransfer c acctnum2 b price m nm)
                    (reqtransfer pm b price pm nm))
                  (dotransfer acctnum2 b price pm nm)))))
          (says c
            (exists ((acctnum2 text))
              (authtransfer c acctnum2 b price m nm)))))
      (3 (and (reqtransfer m b price m nm) (doship m goods c))))))

(defskeleton sorted_epmo_acctnum
  (vars (goods price text) (nm nc nb data) (b m c hash name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nc nb)
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m)))))
  (label 0)
  (unrealized (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum text) (nm nc nb data) (b m c hash name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (precedes ((0 1) (1 0)) ((1 1) (0 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nc nb)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b)) (0 2))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))))
  (label 1)
  (parent 0)
  (unrealized (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nm nc nb data)
    (b m c hash b-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nm) (b b-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 3) nm (1 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0)))))
  (label 2)
  (parent 1)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nm nc nb data)
    (m c hash b name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nm
    (1 0) (enc nc nm m price (pubk c))
    (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))))
  (label 3)
  (parent 2)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nm nc nb nb-0 data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nm) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((0 1) (3 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (1 0)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand bank 2) nm (1 0)
    (enc nc nm m price (pubk c))
    (enc c nc nm acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nm acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 4)
  (parent 2)
  (seen 7)
  (unrealized (0 0) (0 2) (1 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nm nc nb data) (m c hash b name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))))
  (label 5)
  (parent 3)
  (seen 8)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nm nc nb nm-0 data)
    (m c hash b name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc)
    (nm nm-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 6)
  (parent 3)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nm nc nb nb-0 data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nm) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 3) nm (3 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nm acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 7)
  (parent 4)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nm nc nb data) (c hash b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 8)
  (parent 5)
  (unrealized)
  (shape))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nm nc nb nm-0 data)
    (m c hash b name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 9)
  (parent 6)
  (seen 12)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nm nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nm
    (1 0) (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 10)
  (parent 7)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nc nb nb-0 data)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 4 3 bank 2) nm (1 0)
    (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c))
    (enc c nc nm acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 11)
  (parent 7)
  (seen 17)
  (unrealized (0 0) (0 2) (1 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price price-0 acctnum goods text) (nm nc nb nm-0 data)
    (c hash b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (0 0)) ((3 0) (2 0))
    ((3 2) (1 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 12)
  (parent 9)
  (seen 8)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nm nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 13)
  (parent 10)
  (seen 18)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nm nc nb nb-0 nm-0 data) (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc)
    (nm nm-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 14)
  (parent 10)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nb-0
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 15)
  (parent 11)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (3 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 16)
  (parent 11)
  (seen 23)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nc nb nb-0 data)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 17)
  (parent 11)
  (unrealized (0 0) (0 2) (1 0) (3 3))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nm nc nb nb-0 data)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 18)
  (parent 13)
  (seen 8)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nm nc nb nb-0 nm-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 19)
  (parent 14)
  (seen 26)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 20)
  (parent 15)
  (seen 27)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 21)
  (parent 15)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 3 bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 22)
  (parent 16)
  (seen 30)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 23)
  (parent 16)
  (seen 32)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 24)
  (parent 17)
  (seen 34)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nc nb nb-0 data)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 4 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 25)
  (parent 17)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price price-0 acctnum goods text) (nm nc nb nb-0 nm-0 data)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nm)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nm) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 26)
  (parent 19)
  (seen 12)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 data)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 27)
  (parent 20)
  (seen 8)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 28)
  (parent 21)
  (seen 38)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nb-0
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 29)
  (parent 22)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 30)
  (parent 22)
  (unrealized (0 0) (0 2) (1 0) (4 3))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nb-0
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 31)
  (parent 23)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 32)
  (parent 23)
  (seen 25)
  (unrealized (0 0) (0 2) (1 0) (4 3))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 2 bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 33)
  (parent 24)
  (seen 43)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 34)
  (parent 24)
  (seen 25 33)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 35)
  (parent 25)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (3 3))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 36)
  (parent 25)
  (seen 42 47)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 37)
  (parent 25)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price price-0 acctnum goods text) (nc nb nb-0 nm data)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 38)
  (parent 28)
  (seen 12)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 39)
  (parent 29)
  (seen 54)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 40)
  (parent 29)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 41)
  (parent 30)
  (seen 58)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 42)
  (parent 30)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nc nb nb-0 data)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 3 bank 2)
    (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-1)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 43)
  (parent 30)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 44)
  (parent 31)
  (seen 64)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 45)
  (parent 31)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 46)
  (parent 32)
  (seen 68)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 47)
  (parent 32)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 48)
  (parent 33)
  (seen 72)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 49)
  (parent 34)
  (seen 71 73)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 50)
  (parent 35)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 51)
  (parent 35)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 52)
  (parent 37)
  (seen 50 51)
  (unrealized (0 0) (0 2))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 3))
    ((3 0) (0 0)) ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0))
    ((4 1) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 53)
  (parent 37)
  (seen 60 70)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 54)
  (parent 39)
  (seen 18)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nb-1 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 55)
  (parent 40)
  (seen 75)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 56)
  (parent 41)
  (seen 57 71)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-1 (5 0)
    (enc nc nb-1 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 57)
  (parent 41)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 58)
  (parent 41)
  (seen 56 57 71)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 59)
  (parent 42)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 60)
  (parent 42)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 61)
  (parent 43)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (4 3)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 62)
  (parent 43)
  (seen 76 88)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm data) (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 63)
  (parent 43)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 64)
  (parent 44)
  (seen 18)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nb-1 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 65)
  (parent 45)
  (seen 91)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 66)
  (parent 46)
  (seen 72 88)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-1 (5 0)
    (enc nc nb-1 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 67)
  (parent 46)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 68)
  (parent 46)
  (seen 47 66 67 73)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 69)
  (parent 47)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 70)
  (parent 47)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 71)
  (parent 48)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 72)
  (parent 48)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 73)
  (parent 49)
  (seen 67 72)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 74)
  (parent 51)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (price price-0 acctnum goods text) (nc nb nb-0 nb-1 nm data)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (5 1)) ((1 1) (5 3)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 0) (4 0)) ((5 2) (2 0)) ((5 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 75)
  (parent 55)
  (seen 26)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 76)
  (parent 56)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((2 1) (5 0)) ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 77)
  (parent 56)
  (seen 71 105)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nc nb nb-0 data)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 78)
  (parent 57)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 79)
  (parent 57)
  (seen 104 110)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 80)
  (parent 58)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 81)
  (parent 58)
  (seen 71 104 113)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 82)
  (parent 59)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 83)
  (parent 59)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 84)
  (parent 60)
  (seen 82 83)
  (unrealized (0 0) (0 2))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 85)
  (parent 61)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 86)
  (parent 61)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 87)
  (parent 62)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 88)
  (parent 62)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 89)
  (parent 63)
  (seen 85 86)
  (unrealized (0 0) (0 2))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (4 3)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 90)
  (parent 63)
  (seen 103 117 119)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "4 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price price-0 acctnum goods text) (nc nb nb-0 nb-1 nm data)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (5 1)) ((1 1) (5 3)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 0) (4 0)) ((5 2) (2 0)) ((5 2) (3 0))
    ((5 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 91)
  (parent 65)
  (seen 26)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 92)
  (parent 66)
  (seen 71 72)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text) (nc nb nb-0 data)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 93)
  (parent 67)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 94)
  (parent 67)
  (seen 71 125)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 2) (5 0)) ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 95)
  (parent 68)
  (seen 71 73 124)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "4 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 96)
  (parent 69)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 97)
  (parent 69)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 98)
  (parent 70)
  (seen 96 97)
  (unrealized (0 0) (0 2))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 99)
  (parent 71)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 100)
  (parent 72)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (4 0)
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 101)
  (parent 73)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 102)
  (parent 76)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 103)
  (parent 76)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-2 (6 0)
    (enc nc nb-2 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 104)
  (parent 77)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 105)
  (parent 77)
  (seen 110)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 106)
  (parent 78)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 107)
  (parent 78)
  (seen 143)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 108)
  (parent 78)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 2 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 109)
  (parent 79)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 110)
  (parent 79)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 111)
  (parent 80)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 112)
  (parent 80)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 113)
  (parent 81)
  (seen 71 105 110)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nb-1 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 114)
  (parent 83)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 115)
  (parent 86)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 116)
  (parent 87)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 117)
  (parent 87)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 118)
  (parent 88)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 119)
  (parent 88)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-2 (6 0)
    (enc nc nb-2 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 120)
  (parent 92)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 121)
  (parent 93)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 122)
  (parent 93)
  (seen 164)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 123)
  (parent 93)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 124)
  (parent 94)
  (seen 120)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 125)
  (parent 94)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nb-1 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 126)
  (parent 97)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 127)
  (parent 99)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 128)
  (parent 99)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 129)
  (parent 100)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 130)
  (parent 100)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 131)
  (parent 101)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 132)
  (parent 101)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 133)
  (parent 102)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 134)
  (parent 102)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 135)
  (parent 103)
  (seen 133 134)
  (unrealized (0 0) (0 2))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 136)
  (parent 104)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 137)
  (parent 105)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 138)
  (parent 106)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 139)
  (parent 106)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 2 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 140)
  (parent 107)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 141)
  (parent 107)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((5 1) (6 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 5 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 142)
  (parent 107)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 143)
  (parent 107)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 144)
  (parent 108)
  (seen 138 139)
  (unrealized (0 0) (0 2))
  (comment "3 in cohort - 0 not yet seen"))

(comment "Strand bound exceeded--aborting run")

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm nb-1 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (7 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 145)
  (parent 108)
  (unrealized (0 0) (0 2) (1 0) (7 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 146)
  (parent 109)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 147)
  (parent 110)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 148)
  (parent 111)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 149)
  (parent 111)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 150)
  (parent 112)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 nb-2 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 151)
  (parent 113)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 acctnum-1 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-1)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-1)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-1)
    (nb nb-1) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-1)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-1) (nb nb-1) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (price price) (nc nc) (nm nb-1)
    (nb nb-1) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-1)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-1)
  (operation nonce-test (displaced 7 6 bank 2) nb-2 (5 0)
    (enc "hash" c nc nb-1 nb-2 price (pubk hash-2))
    (enc nc nb-2 m price (pubk c))
    (enc c nc nb-2 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-1 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-1 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-1 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-1 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-1 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-1 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-1 m price (pubk c)))
      (send (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) nb-1)))
    ((recv (enc c nc nb-1 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 152)
  (parent 113)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 153)
  (parent 116)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 154)
  (parent 116)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 155)
  (parent 117)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 156)
  (parent 118)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 157)
  (parent 118)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 158)
  (parent 119)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 159)
  (parent 120)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 160)
  (parent 121)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (5 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 161)
  (parent 121)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((2 1) (5 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 162)
  (parent 122)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((4 1) (5 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 4 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 163)
  (parent 122)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 164)
  (parent 122)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 165)
  (parent 123)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nm nb-1 data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 166)
  (parent 123)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 167)
  (parent 124)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 text)
    (nc nb nb-0 nb-1 data) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 168)
  (parent 125)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 169)
  (parent 127)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (6 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 170)
  (parent 127)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 171)
  (parent 128)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 172)
  (parent 129)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (6 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 173)
  (parent 129)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 174)
  (parent 130)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 175)
  (parent 131)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 176)
  (parent 131)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 177)
  (parent 132)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nb-1 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 178)
  (parent 134)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 179)
  (parent 136)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 180)
  (parent 136)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 nb-2 data)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c)) (enc nc nb-2 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-2 (pubk c))))))
  (label 181)
  (parent 137)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nb-2 nm data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-2) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0))
    ((4 2) (6 0)) ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0))
    ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c)) (enc nc nb-2 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 182)
  (parent 137)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (price acctnum goods price-0 text) (nc nb nb-0 nm data)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (goods goods) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 183)
  (parent 139)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 184)
  (parent 140)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 185)
  (parent 140)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 186)
  (parent 141)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 187)
  (parent 141)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((5 1) (6 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 188)
  (parent 142)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((5 1) (6 0)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 189)
  (parent 142)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum goods-0 text) (nc nb nb-0 nb-1 data)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (goods goods-0) (price price)
    (nc nc) (nm nb-0) (nb nb-0) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 190)
  (parent 143)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton sorted_epmo_acctnum
  (vars (goods price acctnum acctnum-0 goods-0 price-0 text)
    (nc nb nb-0 nb-1 nm data)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (goods goods) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (price price) (nc nc) (nm nb-0)
    (nb nb) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (goods goods-0)
    (price price) (nc nc) (nm nb-0) (nb nb-0) (b b-0) (c c) (m m)
    (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-0) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (price price) (nc nc) (nm nb-0)
    (nb nb-1) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (goods goods-0) (price price-0) (nc nc) (nm nm)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 191)
  (parent 143)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))
